'# MWS Version: Version 2021.0 - Sep 08 2020 - ACIS 30.0.1 -

'# length = mm
'# frequency = GHz
'# time = ns
'# frequency range: fmin = 2 fmax = 2.8
'# created = '[VERSION]2021.0|30.0.1|20200908[/VERSION]


'@ use template: Antenna - Planar.cfg

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
'set the units
With Units
    .Geometry "mm"
    .Frequency "GHz"
    .Voltage "V"
    .Resistance "Ohm"
    .Inductance "H"
    .TemperatureUnit  "Kelvin"
    .Time "ns"
    .Current "A"
    .Conductance "Siemens"
    .Capacitance "F"
End With

'----------------------------------------------------------------------------

'set the frequency range
Solver.FrequencyRange "2", "2.8"

'----------------------------------------------------------------------------

Plot.DrawBox True

With Background
     .Type "Normal"
     .Epsilon "1.0"
     .Mu "1.0"
     .XminSpace "0.0"
     .XmaxSpace "0.0"
     .YminSpace "0.0"
     .YmaxSpace "0.0"
     .ZminSpace "0.0"
     .ZmaxSpace "0.0"
End With

With Boundary
     .Xmin "expanded open"
     .Xmax "expanded open"
     .Ymin "expanded open"
     .Ymax "expanded open"
     .Zmin "expanded open"
     .Zmax "expanded open"
     .Xsymmetry "none"
     .Ysymmetry "none"
     .Zsymmetry "none"
End With

' optimize mesh settings for planar structures

With Mesh
     .MergeThinPECLayerFixpoints "True"
     .RatioLimit "20"
     .AutomeshRefineAtPecLines "True", "6"
     .FPBAAvoidNonRegUnite "True"
     .ConsiderSpaceForLowerMeshLimit "False"
     .MinimumStepNumber "5"
     .AnisotropicCurvatureRefinement "True"
     .AnisotropicCurvatureRefinementFSM "True"
End With

With MeshSettings
     .SetMeshType "Hex"
     .Set "RatioLimitGeometry", "20"
     .Set "EdgeRefinementOn", "1"
     .Set "EdgeRefinementRatio", "6"
End With

With MeshSettings
     .SetMeshType "HexTLM"
     .Set "RatioLimitGeometry", "20"
End With

With MeshSettings
     .SetMeshType "Tet"
     .Set "VolMeshGradation", "1.5"
     .Set "SrfMeshGradation", "1.5"
End With

' change mesh adaption scheme to energy
' 		(planar structures tend to store high energy
'     	 locally at edges rather than globally in volume)

MeshAdaption3D.SetAdaptionStrategy "Energy"

' switch on FD-TET setting for accurate farfields

FDSolver.ExtrudeOpenBC "True"

PostProcess1D.ActivateOperation "vswr", "true"
PostProcess1D.ActivateOperation "yz-matrices", "true"

With FarfieldPlot
	.ClearCuts ' lateral=phi, polar=theta
	.AddCut "lateral", "0", "1"
	.AddCut "lateral", "90", "1"
	.AddCut "polar", "90", "1"
End With

'----------------------------------------------------------------------------

Dim sDefineAt As String
sDefineAt = "2;2.4;2.8"
Dim sDefineAtName As String
sDefineAtName = "2;2.4;2.8"
Dim sDefineAtToken As String
sDefineAtToken = "f="
Dim aFreq() As String
aFreq = Split(sDefineAt, ";")
Dim aNames() As String
aNames = Split(sDefineAtName, ";")

Dim nIndex As Integer
For nIndex = LBound(aFreq) To UBound(aFreq)

Dim zz_val As String
zz_val = aFreq (nIndex)
Dim zz_name As String
zz_name = sDefineAtToken & aNames (nIndex)

' Define E-Field Monitors
With Monitor
    .Reset
    .Name "e-field ("& zz_name &")"
    .Dimension "Volume"
    .Domain "Frequency"
    .FieldType "Efield"
    .MonitorValue  zz_val
    .Create
End With

Next

'----------------------------------------------------------------------------

With MeshSettings
     .SetMeshType "Hex"
     .Set "Version", 1%
End With

With Mesh
     .MeshType "PBA"
End With

'set the solver type
ChangeSolverType("HF Time Domain")

'----------------------------------------------------------------------------

'@ define curve 3dpolygon: curve1:3dpolygon1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Polygon3D 
     .Reset 
     .Version 10 
     .Name "3dpolygon1" 
     .Curve "curve1" 
     .Point "10/2", "0", "-2/2" 
     .Point "-10/2", "0", "-2/2" 
     .Create 
End With

'@ define curve rectangle: curve1:rectangle1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Rectangle
     .Reset 
     .Name "rectangle1" 
     .Curve "curve1" 
     .Xrange "10", "30" 
     .Yrange "0.0", "50" 
     .Create
End With

'@ define facefromcovercurve: face1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Face
     .Reset 
     .Name "face1" 
     .Type "CoverCurve" 
     .Curve "curve1:rectangle1" 
     .DeleteCurve "True" 
     .Create
End With

'@ delete curve item: curve1:3dpolygon1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Curve.DeleteCurveItem "curve1", "3dpolygon1"

'@ define curve circle: curve1:circle1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Circle
     .Reset 
     .Name "circle1" 
     .Curve "curve1" 
     .Radius "10" 
     .Xcenter "0.0" 
     .Ycenter "0.0" 
     .Segments "0" 
     .Create
End With

'@ define facefromextrudecurve: face2

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Face
     .Reset 
     .Name "face2" 
     .Type "ExtrudeCurve" 
     .Thickness "10" 
     .Twistangle "0.0" 
     .Taperangle "0.0" 
     .DeleteCurve "True" 
     .Curve "curve1:circle1" 
     .Create
End With

'@ delete face: face1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Face.Delete "face1"

'@ define material: Copper (annealed)

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Material
     .Reset
     .Name "Copper (annealed)"
     .Folder ""
     .FrqType "static"
     .Type "Normal"
     .SetMaterialUnit "Hz", "mm"
     .Epsilon "1"
     .Mu "1.0"
     .Kappa "5.8e+007"
     .TanD "0.0"
     .TanDFreq "0.0"
     .TanDGiven "False"
     .TanDModel "ConstTanD"
     .KappaM "0"
     .TanDM "0.0"
     .TanDMFreq "0.0"
     .TanDMGiven "False"
     .TanDMModel "ConstTanD"
     .DispModelEps "None"
     .DispModelMu "None"
     .DispersiveFittingSchemeEps "Nth Order"
     .DispersiveFittingSchemeMu "Nth Order"
     .UseGeneralDispersionEps "False"
     .UseGeneralDispersionMu "False"
     .FrqType "all"
     .Type "Lossy metal"
     .SetMaterialUnit "GHz", "mm"
     .Mu "1.0"
     .Kappa "5.8e+007"
     .Rho "8930.0"
     .ThermalType "Normal"
     .ThermalConductivity "401.0"
     .SpecificHeat "390", "J/K/kg"
     .MetabolicRate "0"
     .BloodFlow "0"
     .VoxelConvection "0"
     .MechanicsType "Isotropic"
     .YoungsModulus "120"
     .PoissonsRatio "0.33"
     .ThermalExpansionRate "17"
     .Colour "1", "1", "0"
     .Wireframe "False"
     .Reflection "False"
     .Allowoutline "True"
     .Transparentoutline "False"
     .Transparency "0"
     .Create
End With

'@ new component: component1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Component.New "component1"

'@ define brick: component1:solid1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Brick
     .Reset 
     .Name "solid1" 
     .Component "component1" 
     .Material "Copper (annealed)" 
     .Xrange "-50", "59" 
     .Yrange "-50", "50" 
     .Zrange "-10", "10" 
     .Create
End With

'@ define extrude: component1:solid2

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Extrude 
     .Reset 
     .Name "solid2" 
     .Component "component1" 
     .Material "Copper (annealed)" 
     .Mode "Pointlist" 
     .Height "10" 
     .Twist "0.0" 
     .Taper "0.0" 
     .Origin "0.0", "0.0", "0.0" 
     .Uvector "1.0", "0.0", "0.0" 
     .Vvector "0.0", "1.0", "0.0" 
     .Point "10", "10" 
     .LineTo "-10", "10" 
     .LineTo "0", "0" 
     .Create 
End With

'@ delete shape: component1:solid1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Solid.Delete "component1:solid1"

'@ delete face: face2

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Face.Delete "face2"

'@ delete curve: curve1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Curve.DeleteCurve "curve1"

'@ delete shape: component1:solid2

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Solid.Delete "component1:solid2"

'@ define material: dielectric

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Material 
     .Reset 
     .Name "dielectric"
     .Folder ""
     .Rho "0.0"
     .ThermalType "Normal"
     .ThermalConductivity "0"
     .SpecificHeat "0", "J/K/kg"
     .DynamicViscosity "0"
     .Emissivity "0"
     .MetabolicRate "0.0"
     .VoxelConvection "0.0"
     .BloodFlow "0"
     .MechanicsType "Unused"
     .FrqType "all"
     .Type "Normal"
     .MaterialUnit "Frequency", "GHz"
     .MaterialUnit "Geometry", "mm"
     .MaterialUnit "Time", "ns"
     .MaterialUnit "Temperature", "Kelvin"
     .Epsilon "4.08"
     .Mu "1"
     .Sigma "0"
     .TanD "0.015"
     .TanDFreq "0.0"
     .TanDGiven "True"
     .TanDModel "ConstTanD"
     .SetConstTanDStrategyEps "AutomaticOrder"
     .ConstTanDModelOrderEps "3"
     .DjordjevicSarkarUpperFreqEps "0"
     .SetElParametricConductivity "False"
     .ReferenceCoordSystem "Global"
     .CoordSystemType "Cartesian"
     .SigmaM "0"
     .TanDM "0.0"
     .TanDMFreq "0.0"
     .TanDMGiven "False"
     .TanDMModel "ConstTanD"
     .SetConstTanDStrategyMu "AutomaticOrder"
     .ConstTanDModelOrderMu "3"
     .DjordjevicSarkarUpperFreqMu "0"
     .SetMagParametricConductivity "False"
     .DispModelEps "None"
     .DispModelMu "None"
     .DispersiveFittingSchemeEps "Nth Order"
     .MaximalOrderNthModelFitEps "10"
     .ErrorLimitNthModelFitEps "0.1"
     .UseOnlyDataInSimFreqRangeNthModelEps "False"
     .DispersiveFittingSchemeMu "Nth Order"
     .MaximalOrderNthModelFitMu "10"
     .ErrorLimitNthModelFitMu "0.1"
     .UseOnlyDataInSimFreqRangeNthModelMu "False"
     .UseGeneralDispersionEps "False"
     .UseGeneralDispersionMu "False"
     .NLAnisotropy "False"
     .NLAStackingFactor "1"
     .NLADirectionX "1"
     .NLADirectionY "0"
     .NLADirectionZ "0"
     .Colour "0", "1", "1" 
     .Wireframe "False" 
     .Reflection "False" 
     .Allowoutline "True" 
     .Transparentoutline "False" 
     .Transparency "0" 
     .Create
End With

'@ define brick: component1:Sb

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Brick
     .Reset 
     .Name "Sb" 
     .Component "component1" 
     .Material "dielectric" 
     .Xrange "-sbx/2", "sbx/2" 
     .Yrange "sbymin", "sbymax" 
     .Zrange "-sbz/2", "sbz/2" 
     .Create
End With

'@ define extrude: component1:solid1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Extrude 
     .Reset 
     .Name "solid1" 
     .Component "component1" 
     .Material "Copper (annealed)" 
     .Mode "Pointlist" 
     .Height "0" 
     .Twist "0.0" 
     .Taper "0.0" 
     .Origin "0.0", "0.0", "thickness/2" 
     .Uvector "1.0", "0.0", "0.0" 
     .Vvector "0.0", "1.0", "0.0" 
     .Point "-a/2", "0" 
     .LineTo "a/2", "0" 
     .LineTo "b/2", "h" 
     .LineTo "-b/2", "h" 
     .Create 
End With

'@ define cylinder: component1:cccore

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Cylinder 
     .Reset 
     .Name "cccore" 
     .Component "component1" 
     .Material "PEC" 
     .OuterRadius "cca" 
     .InnerRadius "0.0" 
     .Axis "z" 
     .Zrange "cczmin", "thickness/2" 
     .Xcenter "ccx" 
     .Ycenter "ccy" 
     .Segments "0" 
     .Create 
End With

'@ define material: PTFE (loss free)

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Material
     .Reset
     .Name "PTFE (loss free)"
     .Folder ""
     .FrqType "all"
     .Type "Normal"
     .SetMaterialUnit "GHz", "mm"
     .Epsilon "2.1"
     .Mu "1.0"
     .Kappa "0.0"
     .TanD "0.0"
     .TanDFreq "0.0"
     .TanDGiven "False"
     .TanDModel "ConstTanD"
     .KappaM "0.0"
     .TanDM "0.0"
     .TanDMFreq "0.0"
     .TanDMGiven "False"
     .TanDMModel "ConstKappa"
     .DispModelEps "None"
     .DispModelMu "None"
     .DispersiveFittingSchemeEps "General 1st"
     .DispersiveFittingSchemeMu "General 1st"
     .UseGeneralDispersionEps "False"
     .UseGeneralDispersionMu "False"
     .Rho "2200.0"
     .ThermalType "Normal"
     .ThermalConductivity "0.2"
     .SpecificHeat "1000", "J/K/kg"
     .SetActiveMaterial "all"
     .MechanicsType "Isotropic"
     .YoungsModulus "0.5"
     .PoissonsRatio "0.4"
     .ThermalExpansionRate "140"
     .Colour "0.75", "0.95", "0.85"
     .Wireframe "False"
     .Transparency "0"
     .Create
End With

'@ define cylinder: component1:ccinsulator

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Cylinder 
     .Reset 
     .Name "ccinsulator" 
     .Component "component1" 
     .Material "PTFE (loss free)" 
     .OuterRadius "ccb" 
     .InnerRadius "cca" 
     .Axis "z" 
     .Zrange "cczmin", "-thickness/2" 
     .Xcenter "ccx" 
     .Ycenter "ccy" 
     .Segments "0" 
     .Create 
End With

'@ pick face

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Pick.PickFaceFromId "component1:ccinsulator", "2"

'@ define extrude: component1:ccclading

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Extrude 
     .Reset 
     .Name "ccclading" 
     .Component "component1" 
     .Material "PEC" 
     .Mode "Picks" 
     .Height "0.035" 
     .Twist "0.0" 
     .Taper "0.0" 
     .UsePicksForHeight "False" 
     .DeleteBaseFaceSolid "False" 
     .KeepMaterials "False" 
     .ClearPickedFace "True" 
     .Create 
End With

'@ --- execute Macro: Calculate Additional Dispersive Material Information ---

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
' New treefolder created with additional material information for each of the dispersive materials defined so far

'@ Define Material: dielectric (Surface Impedance)

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Material
        .Reset
        .Name "dielectric"
        .Folder "Surface Impedances of Dispersive Materials (Macro)"
        .FrqType "all"
        .Type "Lossy metal"
        .MaterialUnit "Frequency", Units.GetFrequencyUnit
        .MaterialUnit "Geometry", Units.GetGeometryUnit
        .MaterialUnit "Time", Units.GetTimeUnit
        .MaterialUnit "Temperature", "Kelvin"
        .SetTabulatedSurfaceImpedanceModel "Opaque"
        .DispersiveFittingSchemeTabSI "Nth Order"
        .MaximalOrderNthModelFitTabSI "10"
        .ErrorLimitNthModelFitTabSI "0.01"
        .UseOnlyDataInSimFreqRangeNthModelTabSI "True"
        .AddTabulatedSurfaceImpedanceFittingValue "2", "186.309543356603", "1.38654591648432", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2", "186.309543356603", "1.38654591648432", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0008008480072", "186.309933633927", "1.38658859238032", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0016016960144", "186.310334779663", "1.38663134163724", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00240230560303", "186.310735929859", "1.38667400656588", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00320315361023", "186.311126220287", "1.38671642944521", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00400400161743", "186.311527379336", "1.38675892570446", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00480484962463", "186.311917678477", "1.38680117989534", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00560569763184", "186.312318844484", "1.38684359234233", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00640630722046", "186.312709154236", "1.38688559297473", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00680899620056", "186.312915168877", "1.38690700583027", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00720715522766", "186.313110329096", "1.38692783674046", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00800800323486", "186.313500645669", "1.38696975353571", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00880885124207", "186.313901829384", "1.38701182861425", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.00960969924927", "186.314292154673", "1.38705357670234", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01041030883789", "186.314693347243", "1.38709548308721", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01121115684509", "186.315083681251", "1.3871370624617", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01201200485229", "186.315484882677", "1.38717880014642", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0128128528595", "186.315875223507", "1.38722029566937", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0136137008667", "186.316265570559", "1.38726162195786", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0136411190033", "186.316287272377", "1.38726321063559", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01441431045532", "186.316666785236", "1.38730310657661", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01521515846252", "186.317057139112", "1.38734434900555", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01601600646973", "186.317458362648", "1.38738566490852", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01681685447693", "186.317848725244", "1.38742673860303", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01761770248413", "186.318239094062", "1.3874676430524", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01841831207275", "186.318640328956", "1.38750879073741", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.01921916007996", "186.319030704601", "1.38754961131442", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02002000808716", "186.319421084572", "1.3875903475132", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02049660682678", "186.31965966532", "1.38761461497829", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02082085609436", "186.319822332722", "1.38763124209618", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02162170410156", "186.320212723313", "1.38767172466745", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02242231369019", "186.320603114439", "1.38771229260446", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02322316169739", "186.321004375847", "1.38775293407086", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02402400970459", "186.321394777594", "1.38779324837075", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02482485771179", "186.321785183669", "1.38783347828283", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02562570571899", "186.322175594072", "1.38787362380551", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02642631530762", "186.322576871241", "1.38791401263545", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02722716331482", "186.322967290371", "1.3879539893831", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02737522125244", "186.323043212229", "1.38796146090654", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02802801132202", "186.323357711933", "1.38799396661524", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02882885932922", "186.323748139721", "1.38803377457346", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.02962970733643", "186.324138569942", "1.38807358301405", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03043031692505", "186.324539869169", "1.38811354991744", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03123116493225", "186.324930308118", "1.38815318956861", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03203201293945", "186.325320751397", "1.38819274481868", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03283286094666", "186.325711199006", "1.38823221566608", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03363370895386", "186.326101650947", "1.3882716021092", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03427743911743", "186.326416186872", "1.38830317716352", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03443431854248", "186.326492107218", "1.38831090414645", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03523516654968", "186.326893432907", "1.38835036468451", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03603601455688", "186.327283897909", "1.38838949791313", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03683686256409", "186.327674365344", "1.38842863161566", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03763771057129", "186.328064839009", "1.38846759602192", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03843832015991", "186.328455315108", "1.38850656089997", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.03923916816711", "186.328845797437", "1.38854535647749", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04004001617432", "186.3292362822", "1.38858415252469", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04084086418152", "186.329626771295", "1.38862286415435", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04120326042175", "186.329800318778", "1.38864024868038", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04164171218872", "186.330017264723", "1.38866149136487", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04244256019592", "186.330407762484", "1.38870003415466", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04324316978455", "186.330798264578", "1.38873849252213", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04404401779175", "186.331188771005", "1.3887768664657", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04484486579895", "186.331579281766", "1.38881515598375", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04564571380615", "186.33196979686", "1.38885336107472", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04644656181335", "186.33236031439", "1.38889156662796", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04724717140198", "186.332750838152", "1.38892960286049", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04804801940918", "186.33314136435", "1.38896763955317", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04815244674683", "186.33319560983", "1.38897267486159", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04884886741638", "186.333531896781", "1.3890055069209", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.04964971542358", "186.333922431647", "1.38904337474667", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05045056343079", "186.334312970849", "1.38908115813686", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05125117301941", "186.334703514385", "1.38911885708987", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05205202102661", "186.335094062257", "1.38915647160412", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05285286903381", "186.335484614464", "1.38919400167801", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05365371704102", "186.33586430435", "1.3892312042241", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05445456504822", "186.33625486516", "1.38926856540495", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05512547492981", "186.336580332148", "1.38929979911353", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05525517463684", "186.336645430306", "1.38930584214067", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05605602264404", "186.337035997889", "1.38934311932702", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05685687065125", "186.337426571708", "1.38938022716826", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05765771865845", "186.337817147964", "1.38941733545801", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05845856666565", "186.338196861492", "1.3894541161664", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.05925917625427", "186.338587446354", "1.38949105554623", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06006002426147", "186.338978037451", "1.38952782557247", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06086087226868", "186.339368630987", "1.38956459604298", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06166172027588", "186.33975922886", "1.38960128205671", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06212210655212", "186.339976216911", "1.38962219164208", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06246256828308", "186.340138961767", "1.38963772534554", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0632631778717", "186.340529568248", "1.38967424243406", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06406402587891", "186.340920179066", "1.38971067506103", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06486487388611", "186.341310792322", "1.38974710812805", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06566572189331", "186.341690544143", "1.38978312863007", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06646656990051", "186.342081166008", "1.38981939276028", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06726717948914", "186.342471792212", "1.38985557242365", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06806802749634", "186.342851554878", "1.38989142439898", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06886887550354", "186.343242189692", "1.38992743511659", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06914258003235", "186.343372398038", "1.38993960859772", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.06966972351074", "186.343632828845", "1.38996336136259", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07047057151794", "186.344012604258", "1.38999895989395", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07127118110657", "186.344403252022", "1.39003471718469", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07207202911377", "186.344793904126", "1.39007038999908", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07287287712097", "186.345173690387", "1.39010581998079", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07367372512817", "186.345564351103", "1.39014132383097", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07447457313538", "186.345944145842", "1.39017658483196", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.075275182724", "186.34633481327", "1.39021200462166", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0760760307312", "186.346725485039", "1.39024733992812", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07618689537048", "186.346768877536", "1.39025196425367", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0768768787384", "186.347105292529", "1.39028234745063", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07767772674561", "186.347495972912", "1.39031751377867", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07847857475281", "186.347875788881", "1.39035235230533", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.07927918434143", "186.348266477879", "1.39038734964862", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08008003234863", "186.348646300428", "1.39042210408636", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08088088035584", "186.349036998041", "1.39045693243913", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08168172836304", "186.34941682907", "1.39049151787007", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08248257637024", "186.349807533398", "1.39052626214078", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08325529098511", "186.350176524666", "1.39055950113525", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08328318595886", "186.350187374811", "1.39056059364387", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08408403396606", "186.350578087755", "1.39059516891249", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08488488197327", "186.350957935749", "1.39062941631156", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08568572998047", "186.35134865541", "1.39066390748917", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08648657798767", "186.351728511887", "1.39069798586371", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.08728718757629", "186.352108372572", "1.3907319797199", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0880880355835", "186.352499105126", "1.39076621737244", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0888888835907", "186.352878974296", "1.39080004219471", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0896897315979", "186.353269715469", "1.39083411082518", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09034776687622", "186.353584473467", "1.39086189026013", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.0904905796051", "186.353649591222", "1.39086785152731", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09129118919373", "186.354029471185", "1.39090150770435", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09209203720093", "186.354420225254", "1.39093532278717", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09289288520813", "186.354800113702", "1.39096880991624", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09369373321533", "186.355180004459", "1.39100229743767", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09449458122253", "186.355570771426", "1.39103585895922", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09529519081116", "186.355950670669", "1.39106917742487", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09609603881836", "186.356330576025", "1.39110232643345", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09689688682556", "186.356721353989", "1.39113571930378", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09746432304382", "186.356992722144", "1.39115921570564", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09769773483276", "186.357101265931", "1.39116878417089", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09849858283997", "186.357481182084", "1.39120176449995", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.09929919242859", "186.357861102448", "1.39123466028942", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10010004043579", "186.35825189759", "1.39126771503834", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10090088844299", "186.358631824542", "1.3913005266775", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1017017364502", "186.359011757607", "1.39133316884609", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1025025844574", "186.359391692982", "1.39136581139673", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10330319404602", "186.359771632568", "1.39139836940104", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10410404205322", "186.360162447268", "1.39143108639167", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10460495948792", "186.360401274603", "1.39145130677982", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10490489006042", "186.360542395346", "1.39146347530533", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10570573806763", "186.360922347636", "1.39149577966799", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10650658607483", "186.361302304139", "1.39152799947811", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10730719566345", "186.361682264855", "1.39156013473413", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10810804367065", "186.362062227881", "1.39159227036601", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10890889167786", "186.362453068325", "1.39162448008373", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.10970973968506", "186.362833039844", "1.39165644660781", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11051058769226", "186.363213015577", "1.3916883285726", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11131119728088", "186.363592995523", "1.39172012597657", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11177015304565", "186.363810127143", "1.39173833248884", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11211204528809", "186.363972979684", "1.39175183881815", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11291289329529", "186.364352966155", "1.39178355203045", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11371374130249", "186.364732958743", "1.39181509574313", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11451458930969", "186.365112953643", "1.39184663982446", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11531519889832", "186.365492954661", "1.39187801440205", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11611604690552", "186.365872957989", "1.39190938934621", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11691689491272", "186.366252965533", "1.39194067971972", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11771774291992", "186.366632977292", "1.39197188552103", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11851859092712", "186.367012993266", "1.39200300674858", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11895966529846", "186.367230155807", "1.39202036577752", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.11931920051575", "186.367393011552", "1.39203412833962", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12012004852295", "186.367773035956", "1.39206508041552", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12092089653015", "186.368153062673", "1.39209603285285", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12172174453735", "186.36853309551", "1.39212681577091", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12252259254456", "186.368913130658", "1.39215759904832", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12332344055176", "186.369293170023", "1.3921882977437", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12412405014038", "186.3696732117", "1.39221899679742", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12492489814758", "186.370053259498", "1.39224952632461", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12572574615479", "186.370433311512", "1.39227997126512", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12617373466492", "186.370639618924", "1.39229683358632", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12652659416199", "186.370813365839", "1.39231041656087", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12732744216919", "186.371182551553", "1.39234053354561", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12812805175781", "186.371562616152", "1.39237072471152", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12892889976501", "186.371942683064", "1.39240091622957", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.12972974777222", "186.372322752289", "1.39243110809975", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13053059577942", "186.372702827635", "1.39246113042999", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13133144378662", "186.3730829072", "1.39249106816373", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13213205337524", "186.373462989077", "1.39252100624651", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13293290138245", "186.373832201881", "1.39255061596477", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13341212272644", "186.374060257656", "1.39256839230197", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13373374938965", "186.374212292129", "1.39258038484267", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13453459739685", "186.374592386595", "1.39261006911892", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13533544540405", "186.374972485279", "1.39263966879197", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13613605499268", "186.375341714626", "1.39266894006965", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13693690299988", "186.375721821681", "1.39269837052549", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13773775100708", "186.376101931051", "1.39272780132418", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13853859901428", "186.37648204464", "1.39275714751451", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.13933944702148", "186.376851288628", "1.39278616527984", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14014005661011", "186.377231410589", "1.39281534224269", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14067530632019", "186.377481201872", "1.39283471246494", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14094090461731", "186.377611536769", "1.39284443459254", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14174175262451", "186.377980793152", "1.39287319849456", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14254260063171", "186.3783609258", "1.39290220656147", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14334344863892", "186.378741062669", "1.39293113001177", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14414405822754", "186.379110331447", "1.39295964003773", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14494490623474", "186.37949047669", "1.39298839424361", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14574575424194", "186.379870626153", "1.39301706382824", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14654660224915", "186.380239903519", "1.39304548987707", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14734745025635", "186.380620061357", "1.39307399020908", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14796328544617", "186.380902453573", "1.3930957082526", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14814805984497", "186.380989346967", "1.39310224699132", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14894890785217", "186.38136951318", "1.39313057806455", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.14974975585938", "186.38174968171", "1.3931589094672", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15055060386658", "186.382118979719", "1.39318691234132", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15135145187378", "186.382499154719", "1.39321515943692", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1521520614624", "186.382868460974", "1.39324299303021", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1529529094696", "186.383248644351", "1.39327107085472", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15375375747681", "186.383617958853", "1.39329873516109", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15455460548401", "186.383998150607", "1.39332664370835", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15527606010437", "186.384334887984", "1.39335162271892", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15535545349121", "186.38436747145", "1.39335422368368", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15615606307983", "186.384747671582", "1.39338196294806", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15695691108704", "186.385116998766", "1.39340945858881", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15775775909424", "186.385497207278", "1.39343702856468", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15855860710144", "186.385866542709", "1.39346435490327", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.15935945510864", "186.386246757694", "1.39349184054902", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16016006469727", "186.386616101374", "1.39351899757987", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16096091270447", "186.386996324739", "1.39354631392634", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16176176071167", "186.387365676668", "1.39357330164334", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16256260871887", "186.387735030784", "1.39360028966488", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1626136302948", "186.387767631273", "1.39360221115613", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16336345672607", "186.388115266686", "1.39362735204854", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1641640663147", "186.388484629052", "1.39365417074863", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1649649143219", "186.38885399551", "1.39368090478315", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1657657623291", "186.389234242045", "1.39370779815934", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1665666103363", "186.389603614848", "1.39373444783292", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16736745834351", "186.389983869765", "1.39376117188782", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16816806793213", "186.390353250819", "1.39378765222676", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16896891593933", "186.390722635966", "1.39381404789355", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16976976394653", "186.391092025207", "1.39384035888668", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.16997623443604", "186.391189809116", "1.39384714367174", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17057061195374", "186.391472294917", "1.39386682924712", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17137145996094", "186.391841692411", "1.39389297089395", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17217206954956", "186.392211092092", "1.39391911283528", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17297291755676", "186.392591372438", "1.39394541415706", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17377376556396", "186.392960780372", "1.39397138674499", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17457461357117", "186.393330192401", "1.39399727465118", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17537546157837", "186.393699608524", "1.39402307787412", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17617607116699", "186.394069028742", "1.3940487964123", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17697691917419", "186.394449328044", "1.39407475932663", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.17736387252808", "186.394623171753", "1.39408699237037", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1777777671814", "186.39481875461", "1.39410039347297", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1785786151886", "186.395188185271", "1.39412594293103", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1793794631958", "186.395557620027", "1.39415140769927", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18018007278442", "186.395927058879", "1.39417678777621", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18098092079163", "186.39630737714", "1.39420241225249", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18178176879883", "186.396676824248", "1.39422762294815", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18258261680603", "186.397046273544", "1.39425283392726", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18338346481323", "186.397415726937", "1.39427796021", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18418407440186", "186.397785184425", "1.39430300179488", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1847767829895", "186.398056843552", "1.39432151238233", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18498492240906", "186.398154644103", "1.3943280436612", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18578577041626", "186.398524109784", "1.39435291584631", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18658661842346", "186.398893577654", "1.39437778831084", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18738746643066", "186.399263049621", "1.39440257607247", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18818807601929", "186.399632525685", "1.39442727912969", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18898892402649", "186.400002003938", "1.39445198246433", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.18978977203369", "186.400382366129", "1.3944767602813", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19059062004089", "186.400751852641", "1.39450129420633", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.1913914680481", "186.40112134325", "1.39452574342191", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19219207763672", "186.401490837957", "1.39455010792651", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19221472740173", "186.401501706547", "1.39455077704189", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19299292564392", "186.401860336761", "1.39457438771863", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19379377365112", "186.402229837755", "1.39459866778315", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19459462165833", "186.402588466433", "1.3946225339423", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19539546966553", "186.402957975559", "1.39464664457061", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19619607925415", "186.403327488782", "1.39467067048143", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19699692726135", "186.403697004195", "1.39469469666163", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19779777526855", "186.404066525615", "1.39471855313341", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19859862327576", "186.404436049225", "1.39474240987256", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19939947128296", "186.404805576934", "1.39476618188918", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.19967818260193", "186.404936001358", "1.39477446708853", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20020031929016", "186.405175108741", "1.39478986918174", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20100092887878", "186.405544644647", "1.39481347174875", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20180177688599", "186.405914184652", "1.39483698958869", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20260262489319", "186.406283726848", "1.39486050769198", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20340347290039", "186.406642394113", "1.39488369680585", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20420432090759", "186.407011944443", "1.3949070454444", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20500493049622", "186.407381498872", "1.39493030935086", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20580577850342", "186.407751057401", "1.39495348852372", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20660662651062", "186.408120618121", "1.39497666795591", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20716691017151", "186.408370609417", "1.39499265578819", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20740747451782", "186.408490182941", "1.39499976265247", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20820832252502", "186.408848872444", "1.39502252832149", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20900893211365", "186.4092184454", "1.39504545353731", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.20980978012085", "186.409588022455", "1.395068294013", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21061062812805", "186.409957601702", "1.39509113474399", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21141147613525", "186.410316305377", "1.39511364642261", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21221232414246", "186.41068589276", "1.39513631766285", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21301293373108", "186.411055484244", "1.39515890415794", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21381378173828", "186.41142507792", "1.39518149090531", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21461462974548", "186.411783797676", "1.39520366357621", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21468114852905", "186.411816410748", "1.39520558655878", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21541547775269", "186.41215339949", "1.39522608082233", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21621632575989", "186.412523005404", "1.39524841331828", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21701693534851", "186.412881733389", "1.39527050171907", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21781778335571", "186.413251347442", "1.39529266470577", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21861863136292", "186.413620963687", "1.39531482793973", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.21941947937012", "186.41397970372", "1.3953366620596", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22022032737732", "186.414349328103", "1.39535865577683", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22102093696594", "186.414708076148", "1.3953803203674", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22182178497314", "186.415077706761", "1.39540222956584", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22222113609314", "186.4152625248", "1.39541309925246", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22262263298035", "186.415447343386", "1.39542396899962", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22342348098755", "186.415806101571", "1.3954454642929", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22422432899475", "186.416175742517", "1.39546720420636", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22502493858337", "186.416534508715", "1.39548852995797", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22582578659058", "186.416904157801", "1.39551010033721", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22662663459778", "186.417262930102", "1.39553134154815", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22742748260498", "186.41763258733", "1.3955527423877", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22822833061218", "186.417991367645", "1.39557381404658", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22902894020081", "186.418361033013", "1.39559504534045", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22978663444519", "186.418708953567", "1.39561510795883", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.22982978820801", "186.418719819433", "1.39561603245028", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23063063621521", "186.419089491034", "1.39563717920241", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23143148422241", "186.419448285467", "1.39565799675029", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23223233222961", "186.419817963301", "1.39567905895719", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23303294181824", "186.420176765749", "1.3956997069377", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23383378982544", "186.420546451726", "1.39572059958445", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23463463783264", "186.42090526028", "1.39574116300355", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23543548583984", "186.421274954399", "1.39576188608466", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23623633384705", "186.421633769059", "1.39578236493892", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23703694343567", "186.421992589606", "1.3958026739874", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23737788200378", "186.422155697136", "1.39581161176207", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23783779144287", "186.422362293999", "1.39582322772096", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23863863945007", "186.422721118742", "1.39584353721208", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.23943948745728", "186.423090831279", "1.39586392136754", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24024033546448", "186.42344966404", "1.39588406126955", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2410409450531", "186.423808502687", "1.39590403135691", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2418417930603", "186.424178225499", "1.39592424614788", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2426426410675", "186.424537068344", "1.39594421667001", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24344348907471", "186.424895917077", "1.39596401737255", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24424433708191", "186.425265650164", "1.3959840627901", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2449951171875", "186.425602755589", "1.39600260974613", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24504494667053", "186.425624505005", "1.3960037789051", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24584579467773", "186.425983363824", "1.39602341021349", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24664664268494", "186.42634222471", "1.39604304173312", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24744749069214", "186.426711974025", "1.3960627479437", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24824833869934", "186.427070842931", "1.39608220984857", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24904894828796", "186.427429713904", "1.39610167196273", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.24984979629517", "186.427788590767", "1.39612096424355", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.25065064430237", "186.42815835249", "1.39614050126848", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.25145149230957", "186.428517237373", "1.39615962392367", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.25225234031677", "186.428876122413", "1.39617883180705", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.25263810157776", "186.42905013092", "1.39618801597169", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2530529499054", "186.429235013342", "1.3961978698502", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2538537979126", "186.42959390825", "1.39621682307396", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2546546459198", "186.429963688336", "1.3962360210594", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.255455493927", "186.430322589355", "1.39625488966951", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2562563419342", "186.430681492443", "1.39627375848207", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.25705695152283", "186.43104040142", "1.39629245744555", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.25785779953003", "186.431399312466", "1.39631115660953", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.25865864753723", "186.431758227492", "1.39632977094725", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.25945949554443", "186.432117146497", "1.39634830045726", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26026034355164", "186.432476067572", "1.39636683016582", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26030707359314", "186.432497821299", "1.39636791453585", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26106095314026", "186.432834994537", "1.39638519001647", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26186180114746", "186.433204807247", "1.39640379465984", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26266264915466", "186.433563738413", "1.39642215490782", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26346349716187", "186.433922675471", "1.39644034529298", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26426434516907", "186.434281614597", "1.39645853587276", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26506495475769", "186.434640557704", "1.39647664161649", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26586580276489", "186.434999504791", "1.39649466252269", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26666665077209", "186.435358453948", "1.39651268362157", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2674674987793", "186.435717408997", "1.3965305348488", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26800227165222", "186.435956712875", "1.39654246411707", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2682683467865", "186.436076366115", "1.39654838626674", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26906895637512", "186.436435327214", "1.39656615284226", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.26986980438232", "186.436794290383", "1.39658391960752", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27067065238953", "186.437153257533", "1.3966016015284", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27147150039673", "186.437501344234", "1.39661895395826", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27227234840393", "186.437860319284", "1.39663646618195", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27307295799255", "186.438219298315", "1.39665389355687", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27387380599976", "186.438578279416", "1.39667132111761", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27467465400696", "186.438937264499", "1.39668866382761", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27547550201416", "186.439296253563", "1.39670592168541", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.275723695755", "186.439405036104", "1.39671125960476", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27627635002136", "186.439655244697", "1.39672317972708", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27707695960999", "186.440014239814", "1.39674035291458", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27787780761719", "186.440373238912", "1.39675744124645", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27867865562439", "186.440721356999", "1.3967742000404", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.27947950363159", "186.441080363998", "1.39679111865268", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28028035163879", "186.441439373069", "1.39680803744491", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.281081199646", "186.441798386122", "1.39682487137663", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28188180923462", "186.442157401245", "1.39684170548732", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28268265724182", "186.442516422263", "1.39685836969408", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28347134590149", "186.442864561894", "1.39687470433186", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28348350524902", "186.442864559982", "1.3968747893738", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28428435325623", "186.443223586991", "1.39689136888831", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28508520126343", "186.443582617982", "1.39690786353594", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28588581085205", "186.443941651044", "1.39692435835864", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28668665885925", "186.444289802471", "1.39694052359319", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28748750686646", "186.444648843436", "1.39695684867294", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28828835487366", "186.445007886473", "1.3969731739258", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28908920288086", "186.4453560496", "1.39698908453044", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.28988981246948", "186.44571510054", "1.39700524003306", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29069066047668", "186.446074155464", "1.39702131066051", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29124546051025", "186.446313522103", "1.39703222294888", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29149150848389", "186.446422326468", "1.3970371367163", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29229235649109", "186.446781387384", "1.39705312263304", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29309320449829", "186.447140452284", "1.39706902367119", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29389381408691", "186.447488634989", "1.39708459507633", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29469466209412", "186.447847705882", "1.39710041139793", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29549551010132", "186.448206782671", "1.39711605778829", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29629635810852", "186.448554973254", "1.39713154462968", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29709720611572", "186.448914056037", "1.39714710629718", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29789781570435", "186.449262254402", "1.39716242335773", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29869866371155", "186.449621343177", "1.39717790029898", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.2990460395813", "186.449773684322", "1.39718447405534", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.29949951171875", "186.449980435937", "1.39719329235187", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30030035972595", "186.450328646006", "1.39720835473286", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30110120773315", "186.45068774476", "1.39722366205366", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30190181732178", "186.4510359607", "1.39723863969345", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30270266532898", "186.45139506736", "1.39725377722565", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30350351333618", "186.45174328917", "1.39726867012089", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30430436134338", "186.452102401825", "1.39728372291373", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30510520935059", "186.452450631418", "1.39729844600648", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30590581893921", "186.452809751981", "1.39731332900102", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30670666694641", "186.453157987445", "1.39732796734154", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30687308311462", "186.453234165169", "1.39733112697039", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30750751495361", "186.453517114003", "1.39734276558894", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30830836296082", "186.453865357251", "1.39735723411737", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30910921096802", "186.454224489804", "1.39737194761424", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.30990982055664", "186.454572738924", "1.39738633138324", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31071066856384", "186.454920991906", "1.39740063024039", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31151151657104", "186.45528013629", "1.3974150890155", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31231236457825", "186.455628395144", "1.39742930310747", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31311321258545", "186.455987545524", "1.39744367712236", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31391382217407", "186.456335812163", "1.3974577213859", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31471467018127", "186.456684080752", "1.39747176579223", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31472682952881", "186.456694966628", "1.39747209569801", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31551551818848", "186.457043241052", "1.39748597012831", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31631636619568", "186.457391517426", "1.39749984469949", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31711721420288", "186.457739797663", "1.39751363434928", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.3179178237915", "186.458098967883", "1.39752766899735", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31871867179871", "186.458447253993", "1.39754137386708", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.31951951980591", "186.458795543966", "1.39755499381207", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32032036781311", "186.459154724107", "1.39756885876344", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32112121582031", "186.459503019954", "1.39758239392309", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32192182540894", "186.459851319663", "1.39759584415466", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32260727882385", "186.460156086856", "1.39760746435417", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32272267341614", "186.460199623235", "1.39760920945671", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32352352142334", "186.460558817223", "1.39762281977544", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32432436943054", "186.460907126669", "1.39763610028449", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32512521743774", "186.461255439979", "1.39764929586068", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32592582702637", "186.461603755239", "1.39766249157016", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32672667503357", "186.461962963073", "1.39767584723934", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32752752304077", "186.462311286121", "1.39768887308106", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32832837104797", "186.462659611119", "1.39770189905415", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.32912921905518", "186.463007941895", "1.39771475501965", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.3299298286438", "186.463356272707", "1.39772769618459", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33051466941834", "186.463617527836", "1.39773714693291", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.330730676651", "186.463704609296", "1.39774046733907", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.3315315246582", "186.464063836915", "1.39775348353568", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33233237266541", "186.46441217938", "1.39776616987896", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33313322067261", "186.464760525709", "1.39777877127793", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33393383026123", "186.465108873989", "1.39779137280353", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33473467826843", "186.465457226133", "1.39780388938292", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33553552627563", "186.465805582142", "1.39781632101466", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33633637428284", "186.466153942015", "1.39782866769734", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33713722229004", "186.466502303838", "1.39784101450379", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33793783187866", "186.466850669526", "1.39785327635926", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33844876289368", "186.467079287722", "1.39786122755922", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33873867988586", "186.467199037166", "1.39786553833756", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.33953952789307", "186.467547408669", "1.39787771536299", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34034037590027", "186.467895784038", "1.39788980743411", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34114122390747", "186.468244163272", "1.39790181454949", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34194183349609", "186.468592544456", "1.39791382178485", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.3427426815033", "186.468940929506", "1.39792574406257", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.3435435295105", "186.469289318421", "1.39793758138123", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.3443443775177", "186.469637709287", "1.39794941881796", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.3451452255249", "186.469986104018", "1.39796117129372", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34594583511353", "186.470334502614", "1.39797283880708", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34641003608704", "186.47054136658", "1.397979705297", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34674668312073", "186.470682903162", "1.39798450643661", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34754753112793", "186.47103130949", "1.39799600402137", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34834837913513", "186.471379715855", "1.39800758680134", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34914922714233", "186.471728127999", "1.39801899953368", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.34994983673096", "186.472076542096", "1.39803041237934", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35075068473816", "186.472424960058", "1.39804174025593", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35155153274536", "186.472773381885", "1.39805298316204", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35235238075256", "186.473121805665", "1.39806422617955", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35315322875977", "186.473459342584", "1.39807513922996", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35395383834839", "186.473807772121", "1.39808629738267", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35439848899841", "186.474003766387", "1.39809249412536", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35475468635559", "186.474156207437", "1.39809728547636", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35555553436279", "186.474504642792", "1.39810835876382", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35635638237", "186.474853083927", "1.39811926198939", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.3571572303772", "186.475201527014", "1.39813016532257", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35795783996582", "186.475539082877", "1.39814073866503", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35875868797302", "186.475887533635", "1.3981514720359", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.35955953598022", "186.476235986346", "1.39816220551246", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36036038398743", "186.476584442924", "1.39817285400666", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36116123199463", "186.476922012036", "1.39818317249433", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36196208000183", "186.477270476285", "1.39819365101676", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36241388320923", "186.477466487207", "1.39819959309355", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36276268959045", "186.477618942488", "1.39820412964204", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36356353759766", "186.477967410643", "1.39821460837017", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36436438560486", "186.478304993004", "1.39822467198663", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36516523361206", "186.478653468832", "1.39823498073496", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36596608161926", "186.479001946612", "1.39824528958423", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36676669120789", "186.479339538418", "1.39825518330902", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36756753921509", "186.479688023871", "1.39826532217188", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36836838722229", "186.480036513192", "1.39827537604099", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36916923522949", "186.480374112529", "1.3982851849585", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.36997008323669", "186.480722607609", "1.39829515392737", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37045669555664", "186.480929527187", "1.39830108634454", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37077069282532", "186.481071106556", "1.39830503789918", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37157154083252", "186.481408715338", "1.3983146769096", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37237238883972", "186.481757220045", "1.39832447597598", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37317323684692", "186.482094836381", "1.39833394497922", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37397408485413", "186.482443348762", "1.39834357404079", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37477469444275", "186.482791863096", "1.39835320319569", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37557554244995", "186.483129486964", "1.39836258737342", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37637639045715", "186.483478008973", "1.39837204651737", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37717723846436", "186.483815640395", "1.39838126067718", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37797808647156", "186.484164168165", "1.39839063490297", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37852692604065", "186.484392888301", "1.39839688784258", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37877869606018", "186.484501805227", "1.39839976413861", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.37957954406738", "186.484850338757", "1.3984090534434", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38038039207459", "186.485187983375", "1.39841801265224", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38118124008179", "186.485536522665", "1.39842721703274", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38198208808899", "186.485874172923", "1.39843609131041", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38278269767761", "186.48622271989", "1.39844512566253", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38358354568481", "186.486560375788", "1.39845391500579", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38438439369202", "186.486908928516", "1.39846286442653", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38518524169922", "186.487246591971", "1.39847148372991", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38598608970642", "186.487595150459", "1.39848034821598", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38662457466125", "186.487867463856", "1.39848724174089", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38678669929504", "186.487932819555", "1.39848888257794", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38758754730225", "186.4882704924", "1.39849733191481", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38838839530945", "186.488619060458", "1.39850602643972", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38918924331665", "186.488956738944", "1.39851439083004", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.38999009132385", "186.489305314679", "1.39852291530679", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39079070091248", "186.489642998807", "1.39853119474731", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39159154891968", "186.489980686683", "1.39853938915764", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39239239692688", "186.490329270073", "1.39854782876505", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39319324493408", "186.490666963592", "1.39855593822091", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39399409294128", "186.49100466086", "1.39856396264332", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39474987983704", "186.491331468019", "1.3985716569022", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39479470252991", "186.491353255735", "1.39857214715967", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39559555053711", "186.491690958645", "1.39858008662203", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39639639854431", "186.492028665305", "1.3985879410477", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39719724655151", "186.492366373798", "1.39859579554495", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39799809455872", "186.492714980138", "1.39860381014156", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39879870414734", "186.493052696189", "1.39861149456257", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.39959955215454", "186.493390414075", "1.39861917905332", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40040040016174", "186.49372813571", "1.39862677850228", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40120124816895", "186.49407675543", "1.39863453805492", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40200209617615", "186.494414482708", "1.3986420525308", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40280270576477", "186.494752213736", "1.39864948196164", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40290284156799", "186.494795791573", "1.3986504625674", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40360355377197", "186.495089948514", "1.39865682634605", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40440440177917", "186.495427685126", "1.3986641707965", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40520524978638", "186.495776320121", "1.39867167535653", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40600609779358", "186.496114062377", "1.39867893482599", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4068067073822", "186.496451808382", "1.39868610924532", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4076075553894", "186.496789558138", "1.39869319861312", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40840840339661", "186.497127309728", "1.3987002880442", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.40920925140381", "186.497465065068", "1.39870729242191", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41001009941101", "186.497813719149", "1.39871445691556", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41081070899963", "186.498151480134", "1.39872137630204", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41108345985413", "186.498260436485", "1.39872357268077", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41161155700684", "186.498489244868", "1.39872821063191", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41241240501404", "186.498827013353", "1.39873495990376", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41321325302124", "186.499164783673", "1.3987417092352", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41401410102844", "186.499502557744", "1.39874837350678", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41481471061707", "186.499840335565", "1.39875495271712", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41561555862427", "186.50017811522", "1.3987615319852", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41641640663147", "186.500515896711", "1.39876811131101", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41721725463867", "186.500853683868", "1.39877452045198", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41801810264587", "186.50119147286", "1.39878092964884", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4188187122345", "186.501529263688", "1.39878733890159", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.41929197311401", "186.501725402808", "1.3987909862899", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4196195602417", "186.501867060182", "1.39879357796488", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4204204082489", "186.502204858511", "1.39879981708221", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4212212562561", "186.502542658675", "1.39880605625357", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42202210426331", "186.50288046259", "1.39881221035492", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42282271385193", "186.503218270256", "1.39881827938486", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42362356185913", "186.503556079758", "1.39882434846699", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42442440986633", "186.50389389301", "1.39883033247586", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42522525787354", "186.504231710014", "1.39883623141009", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42602610588074", "186.504569528854", "1.39884213039467", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42682671546936", "186.504907351444", "1.39884794430275", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42752838134766", "186.505201586878", "1.39885294765653", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42762756347656", "186.505234281493", "1.39885342791831", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42842841148376", "186.505572109611", "1.39885915679512", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.42922925949097", "186.505909941481", "1.39886480059221", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43003010749817", "186.506247775186", "1.39887044443688", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43083071708679", "186.506585612643", "1.39887600319998", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43163156509399", "186.506923451936", "1.39888156200973", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4324324131012", "186.507261296896", "1.39888695060601", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4332332611084", "186.507588246986", "1.39889209401948", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4340341091156", "186.507926095559", "1.39889748270353", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43483471870422", "186.508263947883", "1.39890278630094", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43563556671143", "186.508601803959", "1.39890800481033", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43579292297363", "186.508667194866", "1.39890905054988", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43643641471863", "186.50892876493", "1.39891297812788", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43723726272583", "186.509266626535", "1.39891811158857", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43803811073303", "186.509604491891", "1.39892315995802", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43883872032166", "186.509942359084", "1.39892820836856", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.43963956832886", "186.510269330937", "1.39893301157838", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44044041633606", "186.510607205574", "1.39893788980008", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44124126434326", "186.510945082048", "1.39894276806103", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44204211235046", "186.511282960358", "1.39894764636123", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44284296035767", "186.511609946925", "1.39895210917992", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44364356994629", "186.511947830764", "1.39895690241949", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44408559799194", "186.512133124412", "1.3989594540888", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44444441795349", "186.512285720272", "1.39896152542351", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44524526596069", "186.512612714029", "1.39896590321024", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4460461139679", "186.51295060715", "1.39897052628551", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4468469619751", "186.513288505939", "1.39897497912065", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44764757156372", "186.513615508803", "1.39897918673168", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44844841957092", "186.513953411206", "1.3989836396344", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.44924926757813", "186.514280419483", "1.39898776217009", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45005011558533", "186.514618329332", "1.39899204485967", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45085096359253", "186.514956241017", "1.39899632758204", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45165157318115", "186.515283258401", "1.39900027992931", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45240640640259", "186.515599375563", "1.39900415731992", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45245242118835", "186.515621175617", "1.39900447757363", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45325326919556", "186.515948198414", "1.39900834483786", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45405411720276", "186.516286123076", "1.39901237225897", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45485496520996", "186.516613151287", "1.39901615443699", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45565557479858", "186.516951081479", "1.39902009677319", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45645642280579", "186.517278117021", "1.39902370871852", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45725727081299", "186.517616052744", "1.3990275659666", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45805811882019", "186.517943091783", "1.39903117796361", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45885896682739", "186.518281034953", "1.39903486497614", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.45965957641602", "186.518608081322", "1.39903830673275", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46046042442322", "186.518946028106", "1.39904199379636", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46075558662415", "186.519065946447", "1.39904324443587", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46126127243042", "186.51927307989", "1.39904535045454", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46206212043762", "186.519611034122", "1.39904886727482", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46286296844482", "186.51993809132", "1.39905213883141", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46366357803345", "186.520276051083", "1.39905557055121", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46446442604065", "186.520603113696", "1.39905875700349", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46526527404785", "186.520930179946", "1.39906185832761", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46606612205505", "186.521268148934", "1.39906511981609", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46686697006226", "186.521595220599", "1.39906813603093", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46766757965088", "186.521933195119", "1.39907131241115", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46846842765808", "186.522260272198", "1.39907424351399", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46913313865662", "186.522532839023", "1.39907662934608", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.46926927566528", "186.522587352915", "1.39907708948373", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47007012367249", "186.522925336661", "1.39908009561984", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47087097167969", "186.523252422792", "1.39908285647261", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47167158126831", "186.523579512561", "1.39908553218911", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47247242927551", "186.523917503617", "1.39908845322577", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47327327728271", "186.524244598801", "1.39909104382078", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47407412528992", "186.524571695707", "1.39909363443015", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47487497329712", "186.524898796249", "1.39909613989965", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47567558288574", "186.525236800226", "1.39909880553815", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47647643089294", "186.525563906184", "1.39910122588029", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47727727890015", "186.52589101578", "1.39910356107943", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47753930091858", "186.526000051416", "1.39910439625221", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47807812690735", "186.526218127096", "1.39910589629022", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47887897491455", "186.526556142079", "1.39910839167156", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.47967958450317", "186.526883260728", "1.39911055659266", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48048043251038", "186.527210381098", "1.39911272152362", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48128128051758", "186.527537505105", "1.39911480130663", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48208212852478", "186.527864630834", "1.39911688109861", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48288297653198", "186.528202660517", "1.39911912106241", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48368358612061", "186.528529793579", "1.39912103055476", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48448443412781", "186.528856928361", "1.39912294005429", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48528528213501", "186.529184064865", "1.399124849561", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48597407341003", "186.529467585583", "1.39912645905371", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48608613014221", "186.529511205007", "1.39912667391437", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48688697814941", "186.529838348786", "1.39912841311305", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48768758773804", "186.530165494287", "1.39913015231713", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48848843574524", "186.530503544146", "1.39913205169459", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.48928928375244", "186.53083069698", "1.3991336205855", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49009013175964", "186.531157851536", "1.39913518948", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49089097976685", "186.531485009729", "1.39913667321487", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49169158935547", "186.531812169644", "1.39913815695244", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49249243736267", "186.532139333197", "1.39913955552859", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49329328536987", "186.532466498471", "1.39914095410654", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49409413337708", "186.532793667384", "1.39914226752128", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49443769454956", "186.532935439644", "1.39914290196128", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49489498138428", "186.533120838018", "1.39914358093693", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4956955909729", "186.53344801229", "1.39914480918756", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4964964389801", "186.533775190201", "1.39914595227185", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.4972972869873", "186.534102369833", "1.39914709535524", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49809813499451", "186.534429553103", "1.3991481532705", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49889898300171", "186.534756738096", "1.39914921118397", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.49969959259033", "186.535083926726", "1.3991501839275", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50050044059753", "186.535411117078", "1.39915115666835", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50130128860474", "186.535738311069", "1.39915204423748", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50210213661194", "186.536065508698", "1.39915284663352", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50290298461914", "186.536392708049", "1.3991536490251", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50292992591858", "186.536403615554", "1.39915363886442", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50370359420776", "186.536719911038", "1.3991543662418", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50450444221497", "186.53704711575", "1.39915508345314", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50530529022217", "186.537363422175", "1.39915547013571", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50610613822937", "186.537690632189", "1.39915610216315", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.50690698623657", "186.538017845842", "1.39915664901215", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5077075958252", "186.538345063134", "1.39915711068136", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5085084438324", "186.538672282147", "1.39915757234251", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5093092918396", "186.538999502883", "1.39915803399561", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5101101398468", "186.539326729174", "1.39915832529271", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.510910987854", "186.539643052946", "1.39915845639575", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51145100593567", "186.539872109514", "1.39915883915755", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51171159744263", "186.53997028454", "1.39915866249783", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51251244544983", "186.54029751594", "1.39915895376446", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51331329345703", "186.540624752896", "1.39915907466974", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51411414146423", "186.540951991574", "1.39915919556338", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51491498947144", "186.541268329364", "1.39915907108237", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51571559906006", "186.541595573345", "1.39915910677476", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51651644706726", "186.541922820966", "1.39915905727708", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51731729507446", "186.542250070309", "1.39915900776595", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51811814308167", "186.542566420453", "1.39915862769663", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51891899108887", "186.5428936751", "1.39915849297847", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.51971960067749", "186.543220933385", "1.39915827306667", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52000141143799", "186.543330022419", "1.39915808618674", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52052044868469", "186.543537290386", "1.39915780777089", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52132129669189", "186.543864553975", "1.39915750264761", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5221221446991", "186.544191819288", "1.3991571975082", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5229229927063", "186.544508185061", "1.39915656180049", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5237238407135", "186.544835457594", "1.39915608626453", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52452445030212", "186.54516273185", "1.39915561071064", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52532529830933", "186.545479106397", "1.39915480458309", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52612614631653", "186.545806385957", "1.39915424380928", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52692699432373", "186.546133669156", "1.39915359783335", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52772784233093", "186.54645005056", "1.39915270646218", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52852845191956", "186.546777339064", "1.39915197526188", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52858066558838", "186.54679915772", "1.3991519549092", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.52932929992676", "186.547093725659", "1.39915099866406", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53013014793396", "186.547421019467", "1.39915018223673", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53093099594116", "186.547748314999", "1.3991493657879", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53173184394836", "186.548064710368", "1.39914821875261", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53253245353699", "186.54839201312", "1.39914723188679", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53333330154419", "186.548708413681", "1.39914599961738", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53413414955139", "186.549035719822", "1.39914501270426", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53493499755859", "186.549352127492", "1.39914361001083", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5357358455658", "186.549679438938", "1.39914253786134", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53653645515442", "186.549995849882", "1.39914113511623", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.537189245224", "186.550257706979", "1.3991400388299", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53733730316162", "186.55032316855", "1.39913989253914", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53813815116882", "186.550639584687", "1.39913840455201", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53893899917603", "186.55096690866", "1.39913707673234", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.53973984718323", "186.551283329989", "1.39913550350056", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54054045677185", "186.551610659267", "1.39913409043567", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54134130477905", "186.551927087706", "1.39913234676537", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54214215278625", "186.552243517755", "1.39913060306525", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54294300079346", "186.552570854003", "1.39912910472273", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54374384880066", "186.552887289244", "1.39912727577094", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54454445838928", "186.553214632716", "1.39912560698397", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54534530639648", "186.553531073149", "1.39912369277746", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54582691192627", "186.553727481825", "1.39912265739452", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54614615440369", "186.553847515193", "1.39912177853938", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54694700241089", "186.554174865635", "1.39912002446549", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54774785041809", "186.554491314788", "1.39911793977486", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54854846000671", "186.554818670536", "1.39911610044199", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.54934930801392", "186.555135124882", "1.39911393048961", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55015015602112", "186.555451580839", "1.39911176050307", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55095100402832", "186.555778945475", "1.39910975067833", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55175185203552", "186.556095406624", "1.39910749542654", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55255246162415", "186.5564118713", "1.39910515494234", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55335330963135", "186.556728337587", "1.39910281442225", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55415415763855", "186.557055712777", "1.39910063406222", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55449414253235", "186.557186669471", "1.39909948927314", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55495500564575", "186.557372184257", "1.39909820827162", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55575585365295", "186.557688659264", "1.39909569724512", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55655646324158", "186.558005137798", "1.39909310098142", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55735731124878", "186.558332523543", "1.39909075007506", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55815815925598", "186.558649005353", "1.39908815373473", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55895900726318", "186.558965490691", "1.39908547215502", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.55975985527039", "186.559281979556", "1.39908270533462", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56056046485901", "186.559609375856", "1.39908018387134", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56136131286621", "186.559925867997", "1.39907741697081", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56216216087341", "186.560242363666", "1.39907456482741", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56296300888062", "186.560558862862", "1.39907162743984", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56319093704224", "186.560646174128", "1.3990707789241", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56376385688782", "186.560875363669", "1.39906869001029", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56456446647644", "186.561191866086", "1.39906575253876", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56536531448364", "186.561508372031", "1.39906272982089", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56616616249084", "186.561835787718", "1.39905986725502", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56696701049805", "186.562152298856", "1.39905675924608", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56776785850525", "186.562468813522", "1.39905356598774", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56856846809387", "186.562785329799", "1.39905037268482", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.56936931610107", "186.563101849603", "1.39904709413077", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57017016410828", "186.563418371017", "1.39904381553126", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57097101211548", "186.563734895959", "1.39904045167889", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57177186012268", "186.564051422512", "1.3990370877802", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57191729545593", "186.564105997739", "1.39903644021428", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5725724697113", "186.564367950675", "1.39903372383518", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57337331771851", "186.564684484284", "1.39903018942641", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57417416572571", "186.565001017585", "1.39902674017873", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57497501373291", "186.565317556332", "1.39902312046468", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57577586174011", "186.565634094772", "1.39901958591174", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57657647132874", "186.565950638657", "1.39901588088982", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57737731933594", "186.566267182235", "1.39901226102899", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57817816734314", "186.566583731259", "1.3990084706966", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57897901535034", "186.566900279976", "1.39900476552529", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.57977986335754", "186.567216834138", "1.39900088987981", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58058047294617", "186.567533387994", "1.39899709939542", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58067345619202", "186.56757704563", "1.39899680282037", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58138132095337", "186.567849947295", "1.39899313843424", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58218216896057", "186.568166506289", "1.39898926263416", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58298301696777", "186.568483070728", "1.39898521635468", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58378386497498", "186.568799634861", "1.3989812552363", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5845844745636", "186.56911620444", "1.39897712363592", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5853853225708", "186.569432773711", "1.39897307719663", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.586186170578", "186.569749348428", "1.39896886027274", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58698701858521", "186.57005501518", "1.39896448310533", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58778786659241", "186.57037159498", "1.39896018085525", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58858847618103", "186.570688174474", "1.39895596376624", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58938932418823", "186.571004759413", "1.39895157618745", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.58945941925049", "186.571026596156", "1.39895112960567", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59019017219543", "186.571321344046", "1.39894727376972", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59099102020264", "186.571637934125", "1.39894280085961", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59179186820984", "186.571943615906", "1.39893816770561", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59259247779846", "186.572260211068", "1.39893360946155", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59339332580566", "186.572576805923", "1.39892913637854", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59419417381287", "186.572893406224", "1.39892449279796", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59499502182007", "186.573199098008", "1.39891968897341", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59579586982727", "186.573515703393", "1.39891496005371", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59659647941589", "186.573832308471", "1.39891031629504", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5973973274231", "186.574148917077", "1.39890558725531", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5981981754303", "186.574454620781", "1.39890052752827", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.59827518463135", "186.574487372921", "1.3989000706332", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5989990234375", "186.574771234471", "1.39889571314511", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.5997998714447", "186.57508785169", "1.39889081347787", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6006007194519", "186.575404470519", "1.39888591374866", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60140132904053", "186.575710184226", "1.39888068332885", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60220217704773", "186.576026808139", "1.39887569825103", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60300302505493", "186.576343433663", "1.39887071311037", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60380387306213", "186.576649155817", "1.39886531205204", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60460472106934", "186.576965786425", "1.39886024155932", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60540533065796", "186.577282420562", "1.39885508577691", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60620617866516", "186.577588149246", "1.39884959929923", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60700702667236", "186.577904788467", "1.39884435816045", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60712099075317", "186.577948462968", "1.39884363523962", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60780787467957", "186.578210520208", "1.3988388715522", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60860872268677", "186.578527164513", "1.39883354505493", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.60940933227539", "186.578843812346", "1.3988281332632", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61021018028259", "186.579149552535", "1.39882247600067", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61101102828979", "186.579466203535", "1.39881706407469", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.611811876297", "186.5797719487", "1.39881132144881", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6126127243042", "186.580088604784", "1.3988058241583", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61341333389282", "186.580394354923", "1.39879999616651", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61421418190002", "186.580711018008", "1.3987943282782", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61501502990723", "186.581016771205", "1.39878850014865", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61581587791443", "186.581333439375", "1.3987827468898", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61599683761597", "186.581398962417", "1.39878132142982", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61661672592163", "186.581639199464", "1.39877674815814", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61741733551025", "186.581955870801", "1.39877099475813", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61821818351746", "186.582261633948", "1.39876499588574", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61901903152466", "186.582578312286", "1.39875907187808", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.61981987953186", "186.582884080408", "1.39875298763043", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62062072753906", "186.58320076383", "1.39874697824449", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62142133712769", "186.583506536928", "1.39874080861906", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62222218513489", "186.583823223517", "1.39873479908722", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62302303314209", "186.584129003507", "1.39872845884649", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62382388114929", "186.584445695181", "1.39872236393206", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62462472915649", "186.584751478229", "1.39871602354381", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62490296363831", "186.584860686139", "1.39871378954316", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62542533874512", "186.585057264696", "1.39870959784531", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62622618675232", "186.585373964928", "1.39870333223431", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62702703475952", "186.58567975637", "1.39869682114867", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62782788276672", "186.585985549314", "1.39869030998775", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62862873077393", "186.586302256186", "1.39868395891126", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.62942934036255", "186.586608054106", "1.39867736236023", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63023018836975", "186.586924766063", "1.39867092589129", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63103103637695", "186.587230568958", "1.3986642439476", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63183188438416", "186.587536375273", "1.3986574766869", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63263273239136", "186.58784218309", "1.39865070934839", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63343334197998", "186.58815890516", "1.39864410208714", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63383936882019", "186.588311814244", "1.39864054786718", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63423418998718", "186.588464717953", "1.39863724935089", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63503503799438", "186.588770534164", "1.39863031129425", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63583588600159", "186.589087262876", "1.39862361855293", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63663673400879", "186.589393082146", "1.3986166803369", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63743734359741", "186.589698904835", "1.39860965679837", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63823819160461", "186.590004729027", "1.3986026331795", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63903903961182", "186.590321467852", "1.39859576962962", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.63983988761902", "186.590627298937", "1.39858857536068", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64064073562622", "186.590933131524", "1.39858138100972", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64144134521484", "186.591238965614", "1.39857418657675", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64224219322205", "186.591544801205", "1.39856699206177", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6428062915802", "186.591763254476", "1.39856192614015", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64304304122925", "186.591861553618", "1.39855987236377", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64384388923645", "186.592167394185", "1.39855259243706", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64464473724365", "186.592473238172", "1.39854522718069", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64544534683228", "186.592779085579", "1.39853777659338", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64624619483948", "186.593084934488", "1.39853032592154", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64704704284668", "186.593390784899", "1.39852287516517", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64784789085388", "186.59369663873", "1.39851533907576", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64864873886108", "186.594013407842", "1.39850796303953", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.64944934844971", "186.594319264732", "1.39850042677843", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65025019645691", "186.594625126958", "1.39849271993242", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65105104446411", "186.59493098877", "1.39848509824953", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65180373191834", "186.59521501068", "1.39847775296499", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65185189247131", "186.595236855918", "1.39847730597922", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65265274047852", "186.595542722652", "1.39846959887203", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65345335006714", "186.595848592806", "1.39846180642633", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65425419807434", "186.596154466379", "1.39845392864087", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65505504608154", "186.596460341454", "1.39844605076667", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65585589408875", "186.596766218032", "1.39843817280373", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65665674209595", "186.59707209803", "1.39843020949891", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65745735168457", "186.59737797953", "1.39842224610452", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65825819969177", "186.59768386445", "1.39841419736658", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65905904769897", "186.597989750872", "1.39840614853821", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.65985989570618", "186.598295640714", "1.39839801436462", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66066074371338", "186.598601532059", "1.39838988009976", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66083168983459", "186.598667080948", "1.39838811267247", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.661461353302", "186.598907424906", "1.39838174574364", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6622622013092", "186.599213321173", "1.39837352604018", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66306304931641", "186.59951922086", "1.39836522098815", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66386389732361", "186.599825122049", "1.39835691584316", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66466474533081", "186.600131024741", "1.39834861060522", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66546535491943", "186.600436930852", "1.39834022001659", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66626620292664", "186.600742838466", "1.39833182933417", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66706705093384", "186.601037836403", "1.39832310792581", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66786789894104", "186.601343748886", "1.39831463179707", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66866874694824", "186.601649662871", "1.39830615557369", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66946935653687", "186.601955580276", "1.39829759399587", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.66989064216614", "186.602119461453", "1.39829317487212", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67027020454407", "186.602261499184", "1.39828903232256", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67107105255127", "186.602567421511", "1.39828038529312", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67187190055847", "186.602873345341", "1.39827173816737", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67267274856567", "186.60316835912", "1.3982627603152", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6734733581543", "186.603474287819", "1.3982540277352", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6742742061615", "186.603780219937", "1.39824520979572", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6750750541687", "186.604086153558", "1.39823639175823", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6758759021759", "186.604392088682", "1.39822757362274", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67667675018311", "186.604687113488", "1.39821842476086", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67747735977173", "186.604993053481", "1.3982095211657", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67827820777893", "186.605298996893", "1.3982005322073", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67898011207581", "186.605561242145", "1.39819252278945", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67907905578613", "186.605604941808", "1.3981915431492", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.67987990379334", "186.605899976192", "1.39818222336454", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68068075180054", "186.606205925976", "1.39817314884177", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68148159980774", "186.606511877262", "1.39816407421848", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68228220939636", "186.606806917859", "1.39815466886898", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68308305740356", "186.607112874014", "1.3981455087781", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68388390541077", "186.607418833589", "1.39813626331854", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68468475341797", "186.607724794667", "1.39812701775677", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68548560142517", "186.608019844842", "1.39811744146878", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68628621101379", "186.608325810788", "1.39810811043442", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.687087059021", "186.60862086381", "1.39809853394289", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6878879070282", "186.608926834625", "1.39808911743388", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.68810081481934", "186.609003333793", "1.39808648616457", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6886887550354", "186.609232806943", "1.39807970082096", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.6894896030426", "186.609527868094", "1.39806995348244", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69029021263123", "186.609833845281", "1.39806045139153", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69109106063843", "186.610139825887", "1.39805086392484", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69189190864563", "186.610434893251", "1.39804103100377", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69269275665283", "186.610740876809", "1.39803144332678", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69349360466003", "186.611035948936", "1.39802152492498", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69429421424866", "186.611341937363", "1.39801185176459", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69509506225586", "186.611637014253", "1.39800184787959", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69589591026306", "186.611943007549", "1.39799208923331", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69669675827026", "186.612249002348", "1.39798233047975", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69725227355957", "186.612456649583", "1.39797539472001", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69749760627747", "186.61254408545", "1.39797224100231", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69829821586609", "186.612850087035", "1.39796231148518", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69909906387329", "186.613145172984", "1.39795222179395", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.69989991188049", "186.613451179438", "1.39794220678468", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7007007598877", "186.61374627015", "1.39793203160326", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7015016078949", "186.614052279555", "1.39792201637579", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70230221748352", "186.614347376948", "1.3979116704253", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70310306549072", "186.614642473821", "1.39790140964341", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70390391349792", "186.614948491461", "1.39789122353275", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70470476150513", "186.615243593097", "1.39788087725533", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70550560951233", "186.61554961369", "1.3978706909231", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70630621910095", "186.615844722006", "1.39786017386924", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70643520355225", "186.615899361839", "1.39785867160016", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70710706710815", "186.616150747468", "1.39784990203532", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70790791511536", "186.616445858631", "1.39783938475987", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70870876312256", "186.616740973108", "1.39782878209406", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.70950961112976", "186.617047004888", "1.39781842464422", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71031022071838", "186.617342124128", "1.39780773647427", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71111106872559", "186.617637242849", "1.39779713347376", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71191191673279", "186.617943282864", "1.39778660512252", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71271276473999", "186.618238408265", "1.39777583133366", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71351361274719", "186.618533535064", "1.3977650574321", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71431422233582", "186.61883957948", "1.39775452873839", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71511507034302", "186.619134711042", "1.39774366932694", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71564912796021", "186.619331466831", "1.39773640122836", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71591591835022", "186.619429845918", "1.39773272451819", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71671676635742", "186.619735898569", "1.39772202491231", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71751761436462", "186.620031036291", "1.39771107987378", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71831822395325", "186.620326175412", "1.39770013472092", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71911907196045", "186.620632234381", "1.39768934948213", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.71991991996765", "186.620927380181", "1.39767823352738", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72072076797485", "186.621222527378", "1.39766711745669", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72152161598206", "186.621517675974", "1.39765600127005", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72232222557068", "186.62182374271", "1.39764513027664", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72312307357788", "186.622118896069", "1.39763392856944", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72392392158508", "186.622414052741", "1.3976226414576", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72472476959229", "186.622709210811", "1.39761135422819", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72489452362061", "186.622774796573", "1.39760907337469", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72552561759949", "186.623004370279", "1.3976000668812", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72632622718811", "186.623310448149", "1.39758902471987", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72712707519531", "186.62360561238", "1.397577651847", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72792792320251", "186.623900779924", "1.39756619356582", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72872877120972", "186.624195948867", "1.39755473516544", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.72952961921692", "186.624491119207", "1.39754327664585", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73033022880554", "186.62478629286", "1.39753173271593", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73113107681274", "186.625081467912", "1.39752018866599", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73193192481995", "186.62538756173", "1.39750888979067", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73273277282715", "186.625682741545", "1.39749726020707", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73353362083435", "186.625977922757", "1.39748563050265", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73417139053345", "186.626207517841", "1.39747619653606", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73433423042297", "186.626273105367", "1.39747400067739", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73513507843018", "186.626568291291", "1.39746228543772", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73593592643738", "186.626863480528", "1.39745048478241", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73673677444458", "186.627158671163", "1.39743868400465", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73753762245178", "186.627453863196", "1.39742688310444", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73833823204041", "186.627749056626", "1.39741508208176", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73913908004761", "186.62804425337", "1.39740319564101", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.73993992805481", "186.628339451512", "1.397391309077", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74074077606201", "186.628634652968", "1.39737933709329", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74154162406921", "186.628929855821", "1.3973673649855", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74234223365784", "186.629225061988", "1.39735530745639", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74314308166504", "186.629520269552", "1.39734324980239", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74347996711731", "186.629640545024", "1.3973381004507", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74394392967224", "186.629815478514", "1.39733119202348", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74474477767944", "186.630110688874", "1.39731913411968", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74554562568665", "186.630405904464", "1.39730690549327", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74634623527527", "186.630701119535", "1.3972947620396", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74714708328247", "186.63099633792", "1.39728253316055", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74794793128967", "186.631291557703", "1.39727030415497", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74874877929688", "186.631586778883", "1.39725807502286", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.74954962730408", "186.631882003377", "1.39724576046335", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7503502368927", "186.632177231185", "1.39723336047522", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7511510848999", "186.63246153986", "1.39722080039787", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7519519329071", "186.632756772327", "1.39720831485316", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75275278091431", "186.633052004276", "1.39719591448196", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75282001495361", "186.633073878119", "1.39719478425426", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75355362892151", "186.633347239538", "1.39718342867972", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75435423851013", "186.633642476198", "1.39717094274851", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75515508651733", "186.633937716172", "1.39715837138463", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75595593452454", "186.634232957543", "1.39714579989096", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75675678253174", "186.634517281337", "1.39713298301479", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75755763053894", "186.634812527368", "1.39712032595809", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75835824012756", "186.635107774797", "1.39710766877079", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75915908813477", "186.635403023623", "1.39709501145288", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.75995993614197", "186.635698275763", "1.39708226869827", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76076078414917", "186.635982611983", "1.39706919526035", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76156163215637", "186.636277866867", "1.39705645224396", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76219201087952", "186.636507517119", "1.39704624708216", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76236248016357", "186.636573125064", "1.39704362378884", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7631630897522", "186.636868386574", "1.39703070989378", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7639639377594", "186.637152728128", "1.39701763593439", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7647647857666", "186.637447992382", "1.39700472177514", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7655656337738", "186.63774325995", "1.39699172217393", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76636648178101", "186.638038528915", "1.39697872243887", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76716709136963", "186.638322879634", "1.39696547733661", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76796793937683", "186.638618153259", "1.39695239202522", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76876878738403", "186.638913428281", "1.39693930657915", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.76956963539124", "186.639197784903", "1.39692597576972", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77037048339844", "186.639493064585", "1.3969128047445", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77117109298706", "186.639788345664", "1.3968996335838", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77159595489502", "186.639941460102", "1.39689257338154", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77197194099426", "186.64007270819", "1.3968862170636", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77277278900146", "186.640367993929", "1.39687296032094", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77357363700867", "186.640663281065", "1.39685970344197", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77437448501587", "186.64094765141", "1.39684611589411", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77517509460449", "186.641242943205", "1.39683277342996", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77597594261169", "186.641527316192", "1.39681918561262", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7767767906189", "186.641822612647", "1.39680575756129", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7775776386261", "186.642117910499", "1.39679232937202", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7783784866333", "186.642402289389", "1.39677865583357", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77917909622192", "186.642697591901", "1.3967651420543", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.77997994422913", "186.642981975348", "1.3967513829283", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78078079223633", "186.643277282519", "1.39673778355662", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78103184700012", "186.643364788446", "1.39673343177909", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78158164024353", "186.643561668608", "1.39672402415758", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78238248825073", "186.643856980438", "1.39671033919149", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78318309783936", "186.644141371085", "1.39669649420133", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78398394584656", "186.644436685658", "1.39668280895652", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78478479385376", "186.644721080862", "1.39666887837325", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78558564186096", "186.645016400095", "1.3966551075304", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78638648986816", "186.645300799856", "1.39664109135165", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78718709945679", "186.645596121832", "1.39662732022805", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78798794746399", "186.64588052615", "1.39661321845182", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78878879547119", "186.646175852786", "1.39659936172658", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.78958964347839", "186.646460261661", "1.39658517435049", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.7903904914856", "186.64675559104", "1.39657131734248", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79049968719482", "186.646788417634", "1.39656923729774", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79119110107422", "186.647040002558", "1.39655712968622", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79199194908142", "186.647324417286", "1.39654285656848", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79279279708862", "186.647619754586", "1.39652882849158", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79359364509583", "186.647904171956", "1.39651455509169", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79439449310303", "186.648199513914", "1.39650044140593", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79519510269165", "186.648483933926", "1.3964861677235", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79599595069885", "186.648768359065", "1.39647172325278", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79679679870605", "186.649063705113", "1.39645760913705", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79759764671326", "186.649348132894", "1.3964431643814", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79839849472046", "186.649632563885", "1.39642863415876", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79919910430908", "186.649927915938", "1.39641443428619", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79999995231628", "186.650212349572", "1.39639990377703", "1.0"
        .AddTabulatedSurfaceImpedanceFittingValue "2.79999995231628", "186.650212349572", "1.39639990377703", "1.0"
        .Create
    End With

'@ --- execute Macro: Calculate Additional Dispersive Material Information ---

'[VERSION]2021.0|30.0.1|20200908[/VERSION]


'@ paste structure data: 1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With SAT 
     .Reset 
     .FileName "*1.cby" 
     .SubProjectScaleFactor "0.001" 
     .ImportToActiveCoordinateSystem "True" 
     .ScaleToUnit "True" 
     .Curves "False" 
     .Read 
End With

'@ delete shape: component1:Sb_1

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Solid.Delete "component1:Sb_1"

'@ define brick: component1:GND

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Brick
     .Reset 
     .Name "GND" 
     .Component "component1" 
     .Material "Copper (annealed)" 
     .Xrange "-sbx/2", "sbx/2" 
     .Yrange "sbymin", "sbymax" 
     .Zrange "-thickness/2", "-thickness/2" 
     .Create
End With

'@ define cylinder: component1:solid2

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
With Cylinder 
     .Reset 
     .Name "solid2" 
     .Component "component1" 
     .Material "PEC" 
     .OuterRadius "ccb" 
     .InnerRadius "0.0" 
     .Axis "z" 
     .Zrange "-thickness/2", "-thickness/2" 
     .Xcenter "ccx" 
     .Ycenter "ccy" 
     .Segments "0" 
     .Create 
End With

'@ boolean subtract shapes: component1:GND, component1:solid2

'[VERSION]2021.0|30.0.1|20200908[/VERSION]
Solid.Subtract "component1:GND", "component1:solid2"

